pub struct ChainMonitor { /* private fields */ }
A ChainMonitor keeps a list of transaction ids to watch for in the blockchain, and some associated information used to apply an action when the id is seen.

Implementations

source

impl ChainMonitor

source

pub fn new(init_height: u64) -> Self

Returns a new ChainMonitor with fields properly initialized.