Struct dlc_manager::contract::contract_input::ContractInput
source · pub struct ContractInput {
pub offer_collateral: u64,
pub accept_collateral: u64,
pub fee_rate: u64,
pub contract_infos: Vec<ContractInputInfo>,
}Expand description
Contains all the information necessary for the initialization of a DLC.
Fields
offer_collateral: u64The collateral for the offering party.
accept_collateral: u64The collateral for the accepting party.
fee_rate: u64The fee rate used to construct the transactions.
contract_infos: Vec<ContractInputInfo>The set of contract that make up the DLC (a single DLC can be based on multiple contracts).