Struct dlc_manager::contract::contract_input::OracleInput
source · pub struct OracleInput {
pub public_keys: Vec<XOnlyPublicKey>,
pub event_id: String,
pub threshold: u16,
}Expand description
Oracle information required for the initial creation of a contract.
Fields
public_keys: Vec<XOnlyPublicKey>The set of public keys for each of the used oracles.
event_id: StringThe id of the event being used for the contract. Note that at the moment a single event id is used, while multiple ids would be preferable.
threshold: u16The number of oracles that need to provide attestations satisfying the contract conditions to be able to close the contract.