Enum dlc_manager::contract::AdaptorInfo
source · pub enum AdaptorInfo {
Enum,
Numerical(MultiOracleTrie),
NumericalWithDifference(MultiOracleTrieWithDiff),
}Expand description
Information about the adaptor signatures and the CET for which they are valid.
Variants
Enum
For enumeration outcome DLC, no special information needs to be kept.
Numerical(MultiOracleTrie)
For numerical outcome DLC, a trie is used to store the information.
NumericalWithDifference(MultiOracleTrieWithDiff)
For numerical outcome DLC where oracles are allowed to diverge to some extent in the outcome value, a trie of trie is used to store the information.