pub enum ContractDescriptor {
    Enum(EnumDescriptor),
    Numerical(NumericalDescriptor),
}
The descriptor of a contract.

Variants



Enum(EnumDescriptor)

Case for enumeration outcome DLC.



Numerical(NumericalDescriptor)

Case for numerical outcome DLC.

Implementations

source

impl ContractDescriptor

source

pub fn get_oracle_params(&self) -> Option<DifferenceParams>

Get the parameters on allowed divergence between oracle if any.

source

pub fn validate(
&self,
announcements: &Vec<OracleAnnouncement>
) -> Result<(), Error>

Validate that all possible outcomes that can be attested by the oracle(s) have a single associated payout.