pub struct ClosedContract {
    pub attestations: Option<Vec<OracleAttestation>>,
    pub signed_cet: Option<Transaction>,
    pub contract_id: ContractId,
    pub temporary_contract_id: ContractId,
    pub counter_party_id: PublicKey,
    pub pnl: i64,
}
Information about a contract that was closed by a CET that was confirmed on the blockchain.

Fields

attestations: Option<Vec<OracleAttestation>>

The attestations that were used to decrypt the broadcast CET.

signed_cet: Option<Transaction>

The signed version of the CET that was broadcast.

contract_id: ContractId

The id of the contract

temporary_contract_id: ContractId

The temporary id of the contract.

counter_party_id: PublicKey

The public key of the counter-party’s node.

pnl: i64

The profit and loss for the given contract