Struct dlc_manager::contract::PreClosedContract
source · pub struct PreClosedContract {
pub signed_contract: SignedContract,
pub attestations: Option<Vec<OracleAttestation>>,
pub signed_cet: Transaction,
}Expand description
Information about a contract that is almost closed by a broadcasted, but not confirmed CET.
Fields
signed_contract: SignedContractThe signed contract that was closed.
attestations: Option<Vec<OracleAttestation>>The attestations that were used to decrypt the broadcast CET.
signed_cet: TransactionThe signed version of the CET that was broadcast.