Oracle

Trait Oracle 

pub trait Oracle {
    // Required methods
    fn get_public_key(&self) -> XOnlyPublicKey;
    fn get_announcement(
        &self,
        event_id: &str,
    ) -> Result<OracleAnnouncement, Error>;
    fn get_attestation(
        &self,
        event_id: &str,
    ) -> Result<OracleAttestation, Error>;
}
Oracle trait provides access to oracle information.

Required Methods

fn get_public_key(&self) -> XOnlyPublicKey

Returns the public key of the oracle.

fn get_announcement(&self, event_id: &str) -> Result<OracleAnnouncement, Error>

Returns the announcement for the event with the given id if found.

fn get_attestation(&self, event_id: &str) -> Result<OracleAttestation, Error>

Returns the attestation for the event with the given id if found.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors