Struct dlc_manager::chain_monitor::ChainMonitor
source · pub struct ChainMonitor { /* private fields */ }Expand description
A ChainMonitor keeps a list of transaction ids to watch for in the blockchain,
and some associated information used to apply an action when the id is seen.
Implementations
sourceimpl ChainMonitor
impl ChainMonitor
sourcepub fn new(init_height: u64) -> Self
pub fn new(init_height: u64) -> Self
Returns a new ChainMonitor with fields properly initialized.