Struct dlc_manager::contract::signed_contract::SignedContract
source · pub struct SignedContract {
pub accepted_contract: AcceptedContract,
pub adaptor_signatures: Option<Vec<EcdsaAdaptorSignature>>,
pub offer_refund_signature: Signature,
pub funding_signatures: FundingSignatures,
pub channel_id: Option<ChannelId>,
}Expand description
Contain information about a contract that was fully signed.
Fields
accepted_contract: AcceptedContractThe accepted contract that was signed.
adaptor_signatures: Option<Vec<EcdsaAdaptorSignature>>The adaptor signatures of the offering party (None if offering party).
offer_refund_signature: SignatureThe refund signature of the offering party.
funding_signatures: FundingSignaturesThe signatures for the funding inputs of the offering party.
channel_id: Option<ChannelId>The ChannelId to which the contract was associated if any.